@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 
-ver=3.02
+ver=4.0
 install_dir=REPLACE_ME
 
 #
@@ -155,7 +155,7 @@ case "$os_name" in
             ACRO_CONFIG=sparcsolaris
             export ACRO_CONFIG
             ;;
-          intel)
+          intel|i386)
             ACRO_CONFIG=intelsolaris
             export ACRO_CONFIG
             ;;
@@ -169,7 +169,7 @@ case "$os_name" in
     ;;
   HP-UX)
     case "$os_release" in
-      *09.0*|*10.*)
+      *09.0*|*10.*|*11.*)
         ACRO_CONFIG=hppahpux
         export ACRO_CONFIG
         ;;
@@ -213,7 +213,7 @@ esac
 
 if [ -z "$ACRO_CONFIG" ] ; then
   echo "The OS named $os_name version $os_release is currently not installed."
-  echo "Try running on a installed platform and connecting to your display."
+  echo "Try running on an installed platform and connecting to your display."
   echo "Installed platform(s) include the following:"
   if [ -d "$ACRO_INSTALL_DIR"/sparcsun ] ; then
     echo "  SPARC/SunOS version 4.1.3 or 4.1.4"
@@ -228,13 +228,13 @@ if [ -z "$ACRO_CONFIG" ] ; then
     echo "  Power PC/Solaris version 2.x"
   fi
   if [ -d "$ACRO_INSTALL_DIR"/hppahpux ] ; then
-    echo "  HP/HP-UX version 9.0.x and 10.x"
+    echo "  HP/HP-UX version 9.0.x, 10.x, and 11.x"
   fi
   if [ -d "$ACRO_INSTALL_DIR"/mipsirix ] ; then
     echo "  MIPS/IRIX version 5.3 and 6.2"
   fi
   if [ -d "$ACRO_INSTALL_DIR"/rs6000aix ] ; then
-    echo "  RS6000/AIX version 4.1.1"
+    echo "  RS6000/AIX version 4.1.1, 4.2, and 4.3"
   fi
   if [ -d "$ACRO_INSTALL_DIR"/intelbsdi ] ; then
     echo "  Intel/BSDI version 2.x"
@@ -279,7 +279,7 @@ case "$ACRO_CONFIG" in
     export XNLSPATH
     ;;
   sparcsolaris|intelsolaris|ppcsolaris)
-    LD_LIBRARY_PATH="`prepend "$ACRO_INSTALL_DIR/$ACRO_CONFIG/lib:$ACRO_INSTALL_DIR/$ACRO_CONFIG/lib" "$LD_LIBRARY_PATH"`"
+    LD_LIBRARY_PATH="`prepend "/usr/dt/lib:$ACRO_INSTALL_DIR/$ACRO_CONFIG/lib:$ACRO_INSTALL_DIR/$ACRO_CONFIG/lib" "$LD_LIBRARY_PATH"`"
     export LD_LIBRARY_PATH
     if [ -z "$LC_CTYPE" ] ; then
       LC_CTYPE="iso_8859_1"
@@ -297,7 +297,7 @@ case "$ACRO_CONFIG" in
     export SHLIB_PATH
     ;;
   rs6000aix)
-    LIBPATH="`prepend "$ACRO_INSTALL_DIR/$ACRO_CONFIG/lib:$ACRO_INSTALL_DIR/$ACRO_CONFIG/lib:/usr/lpp/X11/lib/R5" "$LIBPATH"`"
+    LIBPATH="`prepend "$ACRO_INSTALL_DIR/$ACRO_CONFIG/lib:$ACRO_INSTALL_DIR/$ACRO_CONFIG/lib" "$LIBPATH"`"
     export LIBPATH
     XNLSPATH=/usr/lib/X11/nls
     export XNLSPATH
@@ -314,7 +314,7 @@ case "$ACRO_CONFIG" in
     ;;
 esac
 
-DefaultPSRESPATH="$HOME/psres:$HOME/fonts:/usr/psres:$ACRO_INSTALL_DIR/$ACRO_CONFIG/fonts"
+DefaultPSRESPATH="$HOME/psres:$HOME/fonts:/usr/psres:$ACRO_INSTALL_DIR/$ACRO_CONFIG/fonts:$ACRO_INSTALL_DIR/../Resource/Encoding:$ACRO_INSTALL_DIR/../Resource/CMap"
 if [ -z "$PSRESOURCEPATH" ] ; then
   PSRESOURCEPATH="$DefaultPSRESPATH"
 else
@@ -341,7 +341,7 @@ case "$directory" in
     ;;
   *)
     cmd="acrobat"
-    prod="Acrobat 3.0"
+    prod="Acrobat 4.0"
     ;;
 esac
 
